==> huaweicloudsdkcoc-3.1.120-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/script_list_page.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ScriptListPage:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'data': 'list[ScriptListModel]'
    }

    attribute_map = {
        'total': 'total',
        'data': 'data'
    }

    def __init__(self, total=None, data=None):
        """ScriptListPage

        The model defined in huaweicloud sdk

        :param total: 总条数
        :type total: int
        :param data: 单页数据列表
        :type data: list[:class:`huaweicloudsdkcoc.v1.ScriptListModel`]
        """
        
        

        self._total = None
        self._data = None
        self.discriminator = None

        self.total = total
        self.data = data

    @property
    def total(self):
        """Gets the total of this ScriptListPage.

        总条数

        :return: The total of this ScriptListPage.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ScriptListPage.

        总条数

        :param total: The total of this ScriptListPage.
        :type total: int
        """
        self._total = total

    @property
    def data(self):
        """Gets the data of this ScriptListPage.

        单页数据列表

        :return: The data of this ScriptListPage.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.ScriptListModel`]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this ScriptListPage.

        单页数据列表

        :param data: The data of this ScriptListPage.
        :type data: list[:class:`huaweicloudsdkcoc.v1.ScriptListModel`]
        """
        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScriptListPage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcoc-3.1.154-py2.py3-none-any.whl: huaweicloudsdkcoc/v1/model/script_list_page.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ScriptListPage:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'data': 'list[ScriptListModel]'
    }

    attribute_map = {
        'total': 'total',
        'data': 'data'
    }

    def __init__(self, total=None, data=None):
        r"""ScriptListPage

        The model defined in huaweicloud sdk

        :param total: 总条数
        :type total: int
        :param data: 单页数据列表
        :type data: list[:class:`huaweicloudsdkcoc.v1.ScriptListModel`]
        """
        
        

        self._total = None
        self._data = None
        self.discriminator = None

        self.total = total
        self.data = data

    @property
    def total(self):
        r"""Gets the total of this ScriptListPage.

        总条数

        :return: The total of this ScriptListPage.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ScriptListPage.

        总条数

        :param total: The total of this ScriptListPage.
        :type total: int
        """
        self._total = total

    @property
    def data(self):
        r"""Gets the data of this ScriptListPage.

        单页数据列表

        :return: The data of this ScriptListPage.
        :rtype: list[:class:`huaweicloudsdkcoc.v1.ScriptListModel`]
        """
        return self._data

    @data.setter
    def data(self, data):
        r"""Sets the data of this ScriptListPage.

        单页数据列表

        :param data: The data of this ScriptListPage.
        :type data: list[:class:`huaweicloudsdkcoc.v1.ScriptListModel`]
        """
        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScriptListPage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
